transfer

Function transfer 

pub fn transfer<A: Database + Debug, B: Database + Debug>(
    a: &A,
    b: &mut B,
) -> Result<(), Box<dyn Error>>
where A::Error: 'static, B::Error: 'static,
Transfer data from one Database to another

This function iterates over all sessions and the contained Datasets and transfers the information. No data is cleared, so if the target session was not empty before, the contents will differ.