Json

Struct Json 

pub struct Json { /* private fields */ }
JSON backend

All data is saved in JSON files inside json_folder. The session information is stored directly there with its runs id as filename. This id is also used to create a subfolder where all datasets are stored. For those, the id is used as a filename.

A folder with one session and five datasets could look like this:

9F03105D9451CC3A.json
9F03105D9451CC3A
9F03105D9451CC3A/96ae94e6-cc1a-4621-999c-32a72741e4e8.json
9F03105D9451CC3A/4eac9469-09a4-484c-a7cd-b1aa37d91a6c.json
9F03105D9451CC3A/b9b446a3-78a9-4fe5-b4c1-530759e33282.json
9F03105D9451CC3A/a33a95e6-afd7-4cdf-8e66-54180a77312f.json
9F03105D9451CC3A/c04a2a79-7b13-413f-8f35-523259937101.json

Implementations

Source

impl Json

pub fn new<P: Into<PathBuf>>(json_folder: P) -> Self

Create new JSON backend

Arguments
  • json_folder folder that will contain all JSON files
Source

impl Json