pub struct DatasetWriter { /* private fields */ }Expand description
Wrapper for easier Dataset generation
This type can be used to write data to a file and then automatically generate an id and calculate a hash for the file. The hash algorithm used is SHA-512 (see also Dataset::from_file).
This type implements Write and Seek and therefor can be used together with things like serde_json::to_writer or similar functions.
Example
let mut writer = DatasetWriter::new("output/data")?;
serde_json::to_writer(&mut writer, &[0, 1, 2])?;
let dataset = writer.finalize(())?;
dbsession.add_dataset(&dataset)?;Implementations
Sourceimpl DatasetWriter
impl DatasetWriter
Sourcepub fn new<P: AsRef<Path>>(folder: P) -> Result<Self, Error>
pub fn new<P: AsRef<Path>>(folder: P) -> Result<Self, Error>
Create new writer
This generates an id uses this as a filename to create a file in folder.
If the path did not exist before, parent folders are created.