Struct simuldb::Dataset

source ·
pub struct Dataset {
    pub id: Uuid,
    pub hash: Vec<u8>,
    /* private fields */
}
Reference to one data file

This stores an id to identify to file, a hash to verify it and some metadata that is associated with the data. Note that this does not specify exactly where the file is stored.

By default sha2 is used to generate a SHA-512 hash of the file if the sha feature is enabled. Manually calculating the hash and using from_hash allows for other hash functions as long as the hash is representable as Vec<u8>.

Every time that is serializable into a Map can be used as metadata.

Fields

id: Uuid

Id of file

hash: Vec<u8>

Hash of file

Implementations

source

impl Dataset

source

pub fn from_hash<S: Serialize + Debug>( hash: Vec<u8>, metadata: S, id: Option<Uuid> ) -> Result<Self>

Generate dataset object from externally calculated hash

If no id is specified, a random one will be generated

Arguments
  • hash: hash of the data file
  • metadata: associated metadata, has to be serializable to a Map
  • id: id of the file
source

pub fn from_file<P: AsRef<Path>, S: Serialize + Debug>( path: P, metadata: S, id: Option<Uuid> ) -> Result<Self>

Available on crate feature sha only.

Generate dataset object by calulating the SHA-512 hash of an existing file

If no id is specified, a random one will be generated

Arguments
  • path: path to the data file
  • metadata: associated metadata, has to be serializable to a Map
  • id: id of the file