Value

Enum Value 

pub enum Value {
    Bool(bool),
    String(String),
    Char(char),
    Map(Map),
    Variant(String, Box<Value>),
    StructVariant(String, Map),
    Int(i64),
    Float(Float),
    Seq(Vec<Value>),
    Unit,
}
Generic serialization target type

The available fields correspond to serdes internal data representation.

Drawbacks

There is no destinction between different integer or float types, so numbers that cannot be represented by i64 or f64 are not supported. Also structs are also represented as Map.

Variants



Bool(bool)

Scalar bool value



String(String)

Scalar string value



Char(char)

Scalar char value



Map(Map)

Map from a String key to Value



Variant(String, Box<Value>)

Scalar enum variant



StructVariant(String, Map)

Struct enum variant



Int(i64)

Scalar integer value



Float(Float)

Scalar float value



Seq(Vec<Value>)

List of Values



Unit

Unit type