pub struct Dataset {
pub id: Uuid,
pub hash: Vec<u8>,
/* private fields */
}Expand description
Reference to one data file
This stores an id to identify to file, a hash to verify it and some metadata that is associated with the data.
Note that this does not specify exactly where the file is stored.
By default sha2 is used to generate a SHA-512 hash of the file if the sha feature is enabled.
Manually calculating the hash and using from_hash allows for other hash functions as long as the hash is representable as Vec<u8>.
Every time that is serializable into a Map can be used as metadata.
Fields
id: UuidId of file
hash: Vec<u8>Hash of file
Implementations